@@ -1,5 +1,6 @@
 use crate::{app::Node, input::InputOperation};
 use indexmap::IndexSet;
+use regex::Regex;
 use serde::{Deserialize, Serialize};
 use std::cmp::Ordering;
 
@@ -12,7 +13,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ExplorePwd"
+    /// - Lua: `"ExplorePwd"`
     /// - YAML: `ExplorePwd`
     ExplorePwd,
 
@@ -24,7 +25,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ExplorePwdAsync"
+    /// - Lua: `"ExplorePwdAsync"`
     /// - YAML: `ExplorePwdAsync`
     ExplorePwdAsync,
 
@@ -37,7 +38,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ExploreParentsAsync"
+    /// - Lua: `"ExploreParentsAsync"`
     /// - YAML: `ExploreParentsAsync`
     ExploreParentsAsync,
 
@@ -47,7 +48,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ClearScreen"
+    /// - Lua: `"ClearScreen"`
     /// - YAML: `ClearScreen`
     ClearScreen,
 
@@ -59,7 +60,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "Refresh"
+    /// - Lua: `"Refresh"`
     /// - YAML: `Refresh`
     Refresh,
 
@@ -69,7 +70,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusNext"
+    /// - Lua: `"FocusNext"`
     /// - YAML: `FocusNext`
     FocusNext,
 
@@ -80,7 +81,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { FocusNextByRelativeIndex = 2 }
+    /// - Lua: `{ FocusNextByRelativeIndex = 2 }`
     /// - YAML: `FocusNextByRelativeIndex: 2`
     FocusNextByRelativeIndex(usize),
 
@@ -89,7 +90,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusNextByRelativeIndexFromInput"
+    /// - Lua: `"FocusNextByRelativeIndexFromInput"`
     /// - YAML: `FocusNextByRelativeIndexFromInput`
     FocusNextByRelativeIndexFromInput,
 
@@ -97,13 +98,13 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusPrevious"
+    /// - Lua: `"FocusPrevious"`
     /// - YAML: `FocusPrevious`
     FocusPrevious,
 
     /// Focus on the `-n`th node relative to the current focus where `n` is a
     /// given value.
-    ///  
+    ///
     /// Type: { FocusPreviousByRelativeIndex = int }
     ///
     /// Example:
@@ -117,7 +118,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusPreviousByRelativeIndexFromInput"
+    /// - Lua: `"FocusPreviousByRelativeIndexFromInput"`
     /// - YAML: `FocusPreviousByRelativeIndexFromInput`
     FocusPreviousByRelativeIndexFromInput,
 
@@ -125,7 +126,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusFirst"
+    /// - Lua: `"FocusFirst"`
     /// - YAML: `FocusFirst`
     ///
     FocusFirst,
@@ -133,7 +134,7 @@ pub enum ExternalMsg {
     /// Focus on the last node.
     ///
     /// Example:
-    /// - Lua:  "FocusLast"
+    /// - Lua:  `"FocusLast"`
     /// - YAML: `FocusLast`
     FocusLast,
 
@@ -151,7 +152,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusPathFromInput"
+    /// - Lua: `"FocusPathFromInput"`
     /// - YAML: `FocusPathFromInput`
     FocusPathFromInput,
 
@@ -161,7 +162,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { FocusByIndex = 2 }
+    /// - Lua: `{ FocusByIndex = 2 }`
     /// - YAML: `FocusByIndex: 2`
     FocusByIndex(usize),
 
@@ -169,7 +170,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "FocusByIndexFromInput"
+    /// - Lua: `"FocusByIndexFromInput"`
     /// - YAML: `FocusByIndexFromInput`
     FocusByIndexFromInput,
 
@@ -182,7 +183,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { FocusByFileName = "filename.ext" }
+    /// - Lua: `{ FocusByFileName = "filename.ext" }`
     /// - YAML: `FocusByFileName: filename.ext`
     FocusByFileName(String),
 
@@ -192,7 +193,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ChangeDirectory = "/path/to/directory" }
+    /// - Lua: `{ ChangeDirectory = "/path/to/directory" }`
     /// - YAML: `ChangeDirectory: /path/to/directory`
     ChangeDirectory(String),
 
@@ -200,7 +201,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "Enter"
+    /// - Lua: `"Enter"`
     /// - YAML: `Enter`
     Enter,
 
@@ -208,7 +209,7 @@ pub enum ExternalMsg {
     ///  
     /// Example:
     ///
-    /// - Lua:"Back"
+    /// - Lua: `"Back"`
     /// - YAML: `Back`
     Back,
 
@@ -216,7 +217,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "LastVisitedPath"
+    /// - Lua: `"LastVisitedPath"`
     /// - YAML: `LastVisitedPath`
     LastVisitedPath,
 
@@ -224,7 +225,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "NextVisitedPath"
+    /// - Lua: `"NextVisitedPath"`
     /// - YAML: `NextVisitedPath`
     NextVisitedPath,
 
@@ -233,11 +234,21 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// Lua: "FollowSymlink"
+    /// Lua: `"FollowSymlink"`
     /// YAML: `FollowSymlink`
     FollowSymlink,
 
-    /// ### Reading Input ------------------------------------------------------
+    /// ### Reading Input -----------------------------------------------------
+
+    /// Set the input prompt temporarily, until the input buffer is reset.
+    ///
+    /// Type: { SetInputPrompt = string }
+    ///
+    /// Example:
+    ///
+    /// - Lua: `{ SetInputPrompt = "→" }`
+    /// - YAML: `SetInputPrompt: →`
+    SetInputPrompt(String),
 
     /// Update the input buffer using cursor based operations.
     ///
@@ -245,7 +256,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { UpdateInputBuffer = "GoToPreviousWord" }
+    /// - Lua: `{ UpdateInputBuffer = "GoToPreviousWord" }`
     /// - YAML: `UpdateInputBuffer: GoToPreviousWord`
     UpdateInputBuffer(InputOperation),
 
@@ -253,17 +264,17 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "UpdateInputBufferFromKey"
+    /// - Lua: `"UpdateInputBufferFromKey"`
     /// - YAML: `UpdateInputBufferFromKey`
     UpdateInputBufferFromKey,
 
     /// Append/buffer the given string into the input buffer.
-    ///  
+    ///
     /// Type: { BufferInput = "string" }
     ///
     /// Example:
     ///
-    /// - Lua: { BufferInput = "foo" }
+    /// - Lua: `{ BufferInput = "foo" }`
     /// - YAML: `BufferInput: foo`
     BufferInput(String),
 
@@ -272,27 +283,27 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "BufferInputFromKey"
+    /// - Lua: `"BufferInputFromKey"`
     /// - YAML: `BufferInputFromKey`
     BufferInputFromKey,
 
     /// Set/rewrite the input buffer with the given string.
     /// When the input buffer is not-null (even if empty string)
     /// it will show in the UI.
-    ///  
+    ///
     /// Type: { SetInputBuffer = "string" }
     ///
     /// Example:
     ///
-    /// - Lua: { SetInputBuffer = "foo" }
+    /// - Lua: `{ SetInputBuffer = "foo" }`
     /// - YAML: `SetInputBuffer: foo`
     SetInputBuffer(String),
 
     /// Remove input buffer's last character.
-    ///  
+    ///
     ///  Example:
     ///
-    ///  - Lua: "RemoveInputBufferLastCharacter"
+    ///  - Lua: `"RemoveInputBufferLastCharacter"`
     ///  - YAML: `RemoveInputBufferLastCharacter`
     RemoveInputBufferLastCharacter,
 
@@ -300,7 +311,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "RemoveInputBufferLastWord"
+    /// - Lua: `"RemoveInputBufferLastWord"`
     /// - YAML: `RemoveInputBufferLastWord`
     RemoveInputBufferLastWord,
 
@@ -308,7 +319,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ResetInputBuffer"
+    /// - Lua: `"ResetInputBuffer"`
     /// - YAML: `ResetInputBuffer`
     ResetInputBuffer,
 
@@ -320,7 +331,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchMode = "default" }
+    /// - Lua: `{ SwitchMode = "default" }`
     /// - YAML: SwitchMode: default
     ///
     /// > **NOTE:** To be specific about which mode to switch to, use
@@ -335,7 +346,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchModeKeepingInputBuffer = "default" }
+    /// - Lua: `{ SwitchModeKeepingInputBuffer = "default" }`
     /// - YAML: `SwitchModeKeepingInputBuffer: default`
     ///
     /// > **NOTE:** To be specific about which mode to switch to, use
@@ -350,7 +361,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchModeBuiltin = "default" }
+    /// - Lua: `{ SwitchModeBuiltin = "default" }`
     /// - YAML: `SwitchModeBuiltin: default`
     SwitchModeBuiltin(String),
 
@@ -361,7 +372,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchModeBuiltinKeepingInputBuffer = "default" }
+    /// - Lua: `{ SwitchModeBuiltinKeepingInputBuffer = "default" }`
     /// - YAML: `SwitchModeBuiltinKeepingInputBuffer: default`
     SwitchModeBuiltinKeepingInputBuffer(String),
 
@@ -372,7 +383,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchModeCustom = "my_custom_mode" }
+    /// - Lua: `{ SwitchModeCustom = "my_custom_mode" }`
     /// - YAML: `SwitchModeCustom: my_custom_mode`
     SwitchModeCustom(String),
 
@@ -383,7 +394,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchModeCustomKeepingInputBuffer = "my_custom_mode" }
+    /// - Lua: `{ SwitchModeCustomKeepingInputBuffer = "my_custom_mode" }`
     /// - YAML: `SwitchModeCustomKeepingInputBuffer: my_custom_mode`
     SwitchModeCustomKeepingInputBuffer(String),
 
@@ -392,7 +403,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PopMode"
+    /// - Lua: `"PopMode"`
     /// - YAML: `PopMode`
     PopMode,
 
@@ -401,7 +412,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: PopModeKeepingInputBuffer
+    /// - Lua: `PopModeKeepingInputBuffer`
     /// - YAML: `PopModeKeepingInputBuffer`
     PopModeKeepingInputBuffer,
 
@@ -413,7 +424,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchLayout = "default" }
+    /// - Lua: `{ SwitchLayout = "default" }`
     /// - YAML: `SwitchLayout: default`
     ///
     /// > **NOTE:** To be specific about which layout to switch to, use `SwitchLayoutBuiltin` or
@@ -426,7 +437,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchLayoutBuiltin = "default" }
+    /// - Lua: `{ SwitchLayoutBuiltin = "default" }`
     /// - YAML: `SwitchLayoutBuiltin: default`
     SwitchLayoutBuiltin(String),
 
@@ -436,7 +447,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SwitchLayoutCustom = "my_custom_layout" }
+    /// - Lua: `{ SwitchLayoutCustom = "my_custom_layout" }`
     /// - YAML: `SwitchLayoutCustom: my_custom_layout`
     SwitchLayoutCustom(String),
 
@@ -452,7 +463,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { Call = { command = "bash", args = { "-c", "read -p test" } } }
+    /// - Lua: `{ Call = { command = "bash", args = { "-c", "read -p test" } } }`
     /// - YAML: `Call: { command: bash, args: ["-c", "read -p test"] }`
     Call(Command),
 
@@ -474,7 +485,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { BashExec = "read -p test" }
+    /// - Lua: `{ BashExec = "read -p test" }`
     /// - YAML: `BashExec: "read -p test"`
     BashExec(String),
 
@@ -485,7 +496,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { BashExecSilently = "tput bell" }
+    /// - Lua: `{ BashExecSilently = "tput bell" }`
     /// - YAML: `BashExecSilently: "tput bell"`
     BashExecSilently(String),
 
@@ -502,7 +513,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { CallLua = "custom.some_custom_funtion" }
+    /// - Lua: `{ CallLua = "custom.some_custom_funtion" }`
     /// - YAML: `CallLua: custom.some_custom_funtion`
     CallLua(String),
 
@@ -513,7 +524,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { CallLuaSilently = "custom.some_custom_function" }
+    /// - Lua: `{ CallLuaSilently = "custom.some_custom_function" }`
     /// - YAML: `CallLuaSilently: custom.some_custom_function`
     CallLuaSilently(String),
 
@@ -527,8 +538,8 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LuaEval = [[return { { LogInfo = io.read() } }]] }
-    /// - Lua: { LuaEval = [[function(app) return { { LogInfo = app.pwd } } end]] }
+    /// - Lua: `{ LuaEval = [[return { { LogInfo = io.read() } }]] }`
+    /// - Lua: `{ LuaEval = [[function(app) return { { LogInfo = app.pwd } } end]] }`
     /// - YAML: `LuaEval: "return { { LogInfo = io.read() } }"`
     /// - YAML: `LuaEval: "function(app) return { { LogInfo = app.pwd } } end"`
     LuaEval(String),
@@ -540,7 +551,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LuaEvalSilently = [[return { { LogInfo = "foo" } }]] }
+    /// - Lua: `{ LuaEvalSilently = [[return { { LogInfo = "foo" } }]] }`
     /// - YAML: `LuaEvalSilently: "return { { LogInfo = 'foo' } }"`
     LuaEvalSilently(String),
 
@@ -550,7 +561,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "Select"
+    /// - Lua: `"Select"`
     /// - YAML: `Select`
     Select,
 
@@ -558,7 +569,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "SelectAll"
+    /// - Lua: `"SelectAll"`
     /// - YAML: `SelectAll`
     SelectAll,
 
@@ -568,7 +579,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { SelectPath = "/path/to/file" }
+    /// - Lua: `{ SelectPath = "/path/to/file" }`
     /// - YAML: `SelectPath: /path/to/file`
     SelectPath(String),
 
@@ -576,7 +587,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "UnSelect"
+    /// - Lua: `"UnSelect"`
     /// - YAML: `UnSelect`
     UnSelect,
 
@@ -584,7 +595,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "UnSelectAll"
+    /// - Lua: `"UnSelectAll"`
     /// - YAML: `UnSelectAll`
     UnSelectAll,
 
@@ -594,7 +605,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { UnSelectPath = "/path/to/file" }
+    /// - Lua: `{ UnSelectPath = "/path/to/file" }`
     /// - YAML: `UnSelectPath: /path/to/file`
     UnSelectPath(String),
 
@@ -602,14 +613,14 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ToggleSelection"
+    /// - Lua: `"ToggleSelection"`
     /// - YAML `ToggleSelection`
     ToggleSelection,
 
     /// Toggle between select all and unselect all.
     /// Example:
     ///
-    /// - Lua: "ToggleSelectAll"
+    /// - Lua: `"ToggleSelectAll"`
     /// - YAML: `ToggleSelectAll`
     ToggleSelectAll,
 
@@ -619,7 +630,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ToggleSelectionByPath = "/path/to/file" }
+    /// - Lua: `{ ToggleSelectionByPath = "/path/to/file" }`
     /// - YAML: `ToggleSelectionByPath: /path/to/file`
     ToggleSelectionByPath(String),
 
@@ -627,7 +638,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ClearSelection"
+    /// - Lua: `"ClearSelection"`
     /// - YAML: `ClearSelection`
     ClearSelection,
 
@@ -640,7 +651,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { AddNodeFilter = { filter = "RelativePathDoesStartWith", input = "foo" } }
+    /// - Lua: `{ AddNodeFilter = { filter = "RelativePathDoesStartWith", input = "foo" } }`
     /// - YAML: `AddNodeFilter: { filter: RelativePathDoesStartWith, input: foo }`
     AddNodeFilter(NodeFilterApplicable),
 
@@ -650,7 +661,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { RemoveNodeFilter: { filter: "RelativePathDoesStartWith", input: "foo" } }
+    /// - Lua: `{ RemoveNodeFilter: { filter: "RelativePathDoesStartWith", input: "foo" } }`
     /// - YAML: `RemoveNodeFilter: { filter: RelativePathDoesStartWith, input: foo }`
     RemoveNodeFilter(NodeFilterApplicable),
 
@@ -661,7 +672,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ToggleNodeFilter = { filter = "RelativePathDoesStartWith", input = "foo" } }
+    /// - Lua: `{ ToggleNodeFilter = { filter = "RelativePathDoesStartWith", input = "foo" } }`
     /// - YAML: `ToggleNodeFilter: { filter: RelativePathDoesStartWith, input: foo }`
     ToggleNodeFilter(NodeFilterApplicable),
 
@@ -672,7 +683,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { AddNodeFilterFromInput = "RelativePathDoesStartWith" }
+    /// - Lua: `{ AddNodeFilterFromInput = "RelativePathDoesStartWith" }`
     /// - YAML: `AddNodeFilterFromInput: RelativePathDoesStartWith`
     AddNodeFilterFromInput(NodeFilter),
 
@@ -683,7 +694,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { RemoveNodeFilterFromInput = "RelativePathDoesStartWith" }
+    /// - Lua: `{ RemoveNodeFilterFromInput = "RelativePathDoesStartWith" }`
     /// - YAML: `RemoveNodeFilterFromInput: RelativePathDoesStartWith`
     RemoveNodeFilterFromInput(NodeFilter),
 
@@ -691,7 +702,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "RemoveLastNodeFilter"
+    /// - Lua: `"RemoveLastNodeFilter"`
     /// - YAML: `RemoveLastNodeFilter`
     RemoveLastNodeFilter,
 
@@ -700,7 +711,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ResetNodeFilters"
+    /// - Lua: `"ResetNodeFilters"`
     /// - YAML: `ResetNodeFilters`
     ResetNodeFilters,
 
@@ -708,7 +719,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ClearNodeFilters"
+    /// - Lua: `"ClearNodeFilters"`
     /// - YAML: `ClearNodeFilters`
     ClearNodeFilters,
 
@@ -721,7 +732,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { AddNodeSorter = { sorter = "ByRelativePath", reverse = false } }
+    /// - Lua: `{ AddNodeSorter = { sorter = "ByRelativePath", reverse = false } }`
     /// - YAML: `AddNodeSorter: { sorter: ByRelativePath, reverse: false }`
     AddNodeSorter(NodeSorterApplicable),
 
@@ -731,7 +742,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { RemoveNodeSorter = "ByRelativePath" }
+    /// - Lua: `{ RemoveNodeSorter = "ByRelativePath" }`
     /// - YAML: `RemoveNodeSorter: ByRelativePath`
     RemoveNodeSorter(NodeSorter),
 
@@ -741,7 +752,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ReverseNodeSorter = "ByRelativePath" }
+    /// - Lua: `{ ReverseNodeSorter = "ByRelativePath" }`
     /// - YAML: `ReverseNodeSorter: ByRelativePath`
     ReverseNodeSorter(NodeSorter),
 
@@ -752,7 +763,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ToggleSorterSorter: { sorter = "ByRelativePath", reverse = false } }
+    /// - Lua: `{ ToggleSorterSorter: { sorter = "ByRelativePath", reverse = false } }`
     /// - YAML: `ToggleSorterSorter: {sorter: ByRelativePath, reverse: false }`
     ToggleNodeSorter(NodeSorterApplicable),
 
@@ -760,7 +771,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ReverseNodeSorters"
+    /// - Lua: `"ReverseNodeSorters"`
     /// - YAML: `ReverseNodeSorters`
     ReverseNodeSorters,
 
@@ -768,7 +779,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "RemoveLastNodeSorter"
+    /// - Lua: `"RemoveLastNodeSorter"`
     /// - YAML: `RemoveLastNodeSorter`
     RemoveLastNodeSorter,
 
@@ -777,7 +788,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ResetNodeSorters"
+    /// - Lua: `"ResetNodeSorters"`
     /// - YAML: `ResetNodeSorters`
     ResetNodeSorters,
 
@@ -785,7 +796,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ClearNodeSorters"
+    /// - Lua: `"ClearNodeSorters"`
     /// - YAML: `ClearNodeSorters`
     ClearNodeSorters,
 
@@ -795,7 +806,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "EnableMouse"
+    /// - Lua: `"EnableMouse"`
     /// - YAML: `EnableMouse`
     EnableMouse,
 
@@ -803,7 +814,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "DisableMouse"
+    /// - Lua: `"DisableMouse"`
     /// - YAML: `DisableMouse`
     DisableMouse,
 
@@ -811,7 +822,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "ToggleMouse"
+    /// - Lua: `"ToggleMouse"`
     /// - YAML: `ToggleMouse`
     ToggleMouse,
 
@@ -823,7 +834,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { StartFifo = "/tmp/xplr.fifo }
+    /// - Lua: `{ StartFifo = "/tmp/xplr.fifo }`
     /// - YAML: `StartFifo: /tmp/xplr.fifo`
     StartFifo(String),
 
@@ -831,7 +842,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "StopFifo"
+    /// - Lua: `"StopFifo"`
     /// - YAML: `StopFifo`
     StopFifo,
 
@@ -841,7 +852,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { ToggleFifo = "/path/to/fifo" }
+    /// - Lua: `{ ToggleFifo = "/path/to/fifo" }`
     /// - YAML: `ToggleFifo: /path/to/fifo`
     ToggleFifo(String),
 
@@ -853,7 +864,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LogInfo = "launching satellite" }
+    /// - Lua: `{ LogInfo = "launching satellite" }`
     /// - YAML: `LogInfo: launching satellite`
     LogInfo(String),
 
@@ -863,7 +874,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LogSuccess = "satellite reached destination" }
+    /// - Lua: `{ LogSuccess = "satellite reached destination" }`
     /// - YAML: `LogSuccess: satellite reached destination`
     LogSuccess(String),
 
@@ -873,7 +884,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LogWarning = "satellite is heating" }
+    /// - Lua: `{ LogWarning = "satellite is heating" }`
     /// - YAML: `LogWarning: satellite is heating`
     LogWarning(String),
 
@@ -883,7 +894,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { LogError = "satellite crashed" }
+    /// - Lua: `{ LogError = "satellite crashed" }`
     /// - YAML: `LogError: satellite crashed`
     LogError(String),
 
@@ -896,7 +907,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: { Debug = "/path/to/file" }
+    /// - Lua: `{ Debug = "/path/to/file" }`
     /// - YAML: `Debug: /path/to/file`
     Debug(String),
 
@@ -904,7 +915,7 @@ pub enum ExternalMsg {
 
     /// Example:
     ///
-    /// - Lua: "Quit"
+    /// - Lua: `"Quit"`
     /// - YAML: `Quit`
     ///
     /// Quit with returncode zero (success).
@@ -914,7 +925,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PrintPwdAndQuit"
+    /// - Lua: `"PrintPwdAndQuit"`
     /// - YAML: `PrintPwdAndQuit`
     PrintPwdAndQuit,
 
@@ -923,7 +934,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PrintFocusPathAndQuit"
+    /// - Lua: `"PrintFocusPathAndQuit"`
     /// - YAML: `PrintFocusPathAndQuit`
     PrintFocusPathAndQuit,
 
@@ -932,7 +943,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PrintSelectionAndQuit"
+    /// - Lua: `"PrintSelectionAndQuit"`
     /// - YAML: `PrintSelectionAndQuit`
     PrintSelectionAndQuit,
 
@@ -941,7 +952,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PrintResultAndQuit"
+    /// - Lua: `"PrintResultAndQuit"`
     /// - YAML: `PrintResultAndQuit`
     PrintResultAndQuit,
 
@@ -950,7 +961,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "PrintAppStateAndQuit"
+    /// - Lua: `"PrintAppStateAndQuit"`
     /// - YAML: `PrintAppStateAndQuit`
     PrintAppStateAndQuit,
 
@@ -958,7 +969,7 @@ pub enum ExternalMsg {
     ///
     /// Example:
     ///
-    /// - Lua: "Terminate"
+    /// - Lua: `"Terminate"`
     /// - YAML: `Terminate`
     Terminate,
 }
@@ -992,6 +1003,8 @@ pub enum NodeSorter {
     ByIsReadonly,
     ByMimeEssence,
     BySize,
+    ByCreated,
+    ByLastModified,
 
     ByCanonicalAbsolutePath,
     ByICanonicalAbsolutePath,
@@ -1001,6 +1014,8 @@ pub enum NodeSorter {
     ByCanonicalIsReadonly,
     ByCanonicalMimeEssence,
     ByCanonicalSize,
+    ByCanonicalCreated,
+    ByCanonicalLastModified,
 
     BySymlinkAbsolutePath,
     ByISymlinkAbsolutePath,
@@ -1010,6 +1025,8 @@ pub enum NodeSorter {
     BySymlinkIsReadonly,
     BySymlinkMimeEssence,
     BySymlinkSize,
+    BySymlinkCreated,
+    BySymlinkLastModified,
 }
 
 #[derive(Debug, Clone, Eq, Serialize, Deserialize)]
@@ -1054,6 +1071,8 @@ impl NodeSorterApplicable {
             NodeSorter::ByIsReadonly => a.is_readonly.cmp(&b.is_readonly),
             NodeSorter::ByMimeEssence => a.mime_essence.cmp(&b.mime_essence),
             NodeSorter::BySize => a.size.cmp(&b.size),
+            NodeSorter::ByCreated => a.created.cmp(&b.created),
+            NodeSorter::ByLastModified => a.last_modified.cmp(&b.last_modified),
 
             NodeSorter::ByCanonicalAbsolutePath => natord::compare(
                 &a.canonical
@@ -1115,6 +1134,18 @@ impl NodeSorterApplicable {
                 .map(|s| &s.size)
                 .cmp(&b.canonical.as_ref().map(|s| &s.size)),
 
+            NodeSorter::ByCanonicalCreated => a
+                .canonical
+                .as_ref()
+                .map(|s| &s.created)
+                .cmp(&b.canonical.as_ref().map(|s| &s.created)),
+
+            NodeSorter::ByCanonicalLastModified => a
+                .canonical
+                .as_ref()
+                .map(|s| &s.last_modified)
+                .cmp(&b.canonical.as_ref().map(|s| &s.last_modified)),
+
             NodeSorter::BySymlinkAbsolutePath => natord::compare(
                 &a.symlink
                     .as_ref()
@@ -1172,6 +1203,18 @@ impl NodeSorterApplicable {
                 .as_ref()
                 .map(|s| &s.size)
                 .cmp(&b.symlink.as_ref().map(|s| &s.size)),
+
+            NodeSorter::BySymlinkCreated => a
+                .symlink
+                .as_ref()
+                .map(|s| &s.created)
+                .cmp(&b.symlink.as_ref().map(|s| &s.created)),
+
+            NodeSorter::BySymlinkLastModified => a
+                .symlink
+                .as_ref()
+                .map(|s| &s.last_modified)
+                .cmp(&b.symlink.as_ref().map(|s| &s.last_modified)),
         };
         if self.reverse {
             order.reverse()
@@ -1208,6 +1251,12 @@ pub enum NodeFilter {
     IRelativePathDoesEndWith,
     IRelativePathDoesNotEndWith,
 
+    RelativePathDoesMatchRegex,
+    RelativePathDoesNotMatchRegex,
+
+    IRelativePathDoesMatchRegex,
+    IRelativePathDoesNotMatchRegex,
+
     AbsolutePathIs,
     AbsolutePathIsNot,
 
@@ -1231,6 +1280,12 @@ pub enum NodeFilter {
 
     IAbsolutePathDoesEndWith,
     IAbsolutePathDoesNotEndWith,
+
+    AbsolutePathDoesMatchRegex,
+    AbsolutePathDoesNotMatchRegex,
+
+    IAbsolutePathDoesMatchRegex,
+    IAbsolutePathDoesNotMatchRegex,
 }
 
 impl NodeFilter {
@@ -1293,6 +1348,24 @@ impl NodeFilter {
                 .to_lowercase()
                 .ends_with(&input.to_lowercase()),
 
+            Self::RelativePathDoesMatchRegex => Regex::new(input)
+                .map(|r| r.is_match(&node.relative_path))
+                .unwrap_or(false),
+            Self::IRelativePathDoesMatchRegex => {
+                Regex::new(&input.to_lowercase())
+                    .map(|r| r.is_match(&node.relative_path.to_lowercase()))
+                    .unwrap_or(false)
+            }
+
+            Self::RelativePathDoesNotMatchRegex => !Regex::new(input)
+                .map(|r| r.is_match(&node.relative_path))
+                .unwrap_or(false),
+            Self::IRelativePathDoesNotMatchRegex => {
+                !Regex::new(&input.to_lowercase())
+                    .map(|r| r.is_match(&node.relative_path.to_lowercase()))
+                    .unwrap_or(false)
+            }
+
             Self::AbsolutePathIs => node.absolute_path.eq(input),
             Self::IAbsolutePathIs => {
                 node.absolute_path.eq_ignore_ascii_case(input)
@@ -1348,6 +1421,24 @@ impl NodeFilter {
                 .absolute_path
                 .to_lowercase()
                 .ends_with(&input.to_lowercase()),
+
+            Self::AbsolutePathDoesMatchRegex => Regex::new(input)
+                .map(|r| r.is_match(&node.absolute_path))
+                .unwrap_or(false),
+            Self::IAbsolutePathDoesMatchRegex => {
+                Regex::new(&input.to_lowercase())
+                    .map(|r| r.is_match(&node.absolute_path.to_lowercase()))
+                    .unwrap_or(false)
+            }
+
+            Self::AbsolutePathDoesNotMatchRegex => !Regex::new(input)
+                .map(|r| r.is_match(&node.absolute_path))
+                .unwrap_or(false),
+            Self::IAbsolutePathDoesNotMatchRegex => {
+                !Regex::new(&input.to_lowercase())
+                    .map(|r| r.is_match(&node.absolute_path.to_lowercase()))
+                    .unwrap_or(false)
+            }
         }
     }
 }
