@@ -6,7 +6,7 @@ use crate::cli::Cli;
 use crate::event_reader::EventReader;
 use crate::explorer;
 use crate::lua;
-use crate::pipe_reader;
+use crate::pipe;
 use crate::pwd_watcher;
 use crate::ui;
 use anyhow::{bail, Error, Result};
@@ -80,6 +80,7 @@ fn call(app: &app::App, cmd: app::Command, silent: bool) -> Result<ExitStatus> {
         .env(
             "XPLR_INPUT_BUFFER",
             app.input
+                .buffer
                 .as_ref()
                 .map(|i| i.value().to_string())
                 .unwrap_or_default(),
@@ -486,7 +487,7 @@ impl Runner {
                                     })
                                     .unwrap_or_else(|e| Err(e.to_string()));
 
-                                match pipe_reader::read_all(&app.pipe.msg_in) {
+                                match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
                                         app = app
                                             .handle_batch_external_msgs(msgs)?;
@@ -723,7 +724,7 @@ impl Runner {
                                     .unwrap_or_else(|e| Err(e.to_string()));
 
                                 // TODO remove duplicate segment
-                                match pipe_reader::read_all(&app.pipe.msg_in) {
+                                match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
                                         app = app
                                             .handle_batch_external_msgs(msgs)?;
