@@ -375,6 +375,8 @@ pub struct ResolvedNodeUiMetadata {
     pub mime_essence: String,
     pub size: u64,
     pub human_size: String,
+    pub created: Option<u128>,
+    pub last_modified: Option<u128>,
 }
 
 impl From<ResolvedNode> for ResolvedNodeUiMetadata {
@@ -388,6 +390,8 @@ impl From<ResolvedNode> for ResolvedNodeUiMetadata {
             mime_essence: node.mime_essence.to_owned(),
             size: node.size,
             human_size: node.human_size,
+            created: node.created,
+            last_modified: node.last_modified,
         }
     }
 }
@@ -410,6 +414,8 @@ pub struct NodeUiMetadata {
     pub permissions: Permissions,
     pub canonical: Option<ResolvedNodeUiMetadata>,
     pub symlink: Option<ResolvedNodeUiMetadata>,
+    pub created: Option<u128>,
+    pub last_modified: Option<u128>,
 
     // Extra
     pub index: usize,
@@ -456,6 +462,8 @@ impl NodeUiMetadata {
             permissions: node.permissions.to_owned(),
             canonical: node.canonical.to_owned().map(ResolvedNode::into),
             symlink: node.symlink.to_owned().map(ResolvedNode::into),
+            created: node.created,
+            last_modified: node.last_modified,
             index,
             relative_index,
             is_before_focus,
@@ -801,7 +809,7 @@ fn draw_input_buffer<B: Backend>(
     app: &app::App,
     _: &Lua,
 ) {
-    if let Some(input) = app.input.as_ref() {
+    if let Some(input) = app.input.buffer.as_ref() {
         let panel_config = &app.config.general.panel_ui;
         let config = panel_config
             .default
@@ -817,14 +825,7 @@ fn draw_input_buffer<B: Backend>(
             1
         } else {
             0
-        } + app
-            .config
-            .general
-            .prompt
-            .format
-            .as_ref()
-            .map(|t| t.chars().count() as u16)
-            .unwrap_or(0);
+        } + app.input.prompt.chars().count() as u16;
 
         let cursor_offset_right = if config
             .borders
@@ -843,12 +844,7 @@ fn draw_input_buffer<B: Backend>(
 
         let input_buf = Paragraph::new(Spans::from(vec![
             Span::styled(
-                app.config
-                    .general
-                    .prompt
-                    .format
-                    .to_owned()
-                    .unwrap_or_default(),
+                app.input.prompt.to_owned(),
                 app.config.general.prompt.style.to_owned().into(),
             ),
             Span::raw(input.value()),
@@ -1271,7 +1267,7 @@ pub fn draw_layout<B: Backend>(
             draw_selection(f, screen_size, layout_size, app, lua)
         }
         Layout::InputAndLogs => {
-            if app.input.is_some() {
+            if app.input.buffer.is_some() {
                 draw_input_buffer(f, screen_size, layout_size, app, lua);
             } else {
                 draw_logs(f, screen_size, layout_size, app, lua);
